@@ -37,7 +37,7 @@ class BitmexClient:
                 position = self.client.Position.Position_get(
                     filter=json.dumps({'symbol': symbol})).result()[0][0][str(prop)]
                 break
-            except (IndexError, HTTPBadRequest) as e:
+            except (IndexError, HTTPBadRequest, HTTPBadGateway) as e:
                 if 'expired' in str(e):
                     print('Getting open contracts in {} failed. Expired error.'.format(
                         symbol), flush=True)
@@ -163,7 +163,7 @@ class BitmexOrder:
         self.props = {}
         for symbol in symbols:
             self.props[symbol] = {
-                'stoploss_id': '', 'stop_id': '', 'entry': .0, 'SL': .0, 'TP': .0, 'open': False, 'wait_stop': False, 'qty': 0}
+                'stoploss_id': '', 'stop_id': '', 'entry': .0, 'SL': .0, 'TP': .0, 'open': False, 'wait_stop': False, 'qty': 0, 'initialSL': .0}
 
         self.show_slippage = False  # only for testing
         if self.show_slippage:
@@ -395,7 +395,6 @@ class BitmexOrder:
     def bracket_stop_order(self, symbol, orderQty, entry, sl, tp=0):
         try:
             if self.props[symbol]['qty'] != 0:
-                print("order is open -> close old order first", flush=True)
                 self.close(symbol)
                 time.sleep(1)
             self.props[symbol]['stop_id'] = self.generate_id(symbol)
